cheesecake.model.ModuleVistor

Package cheesecake :: Module model :: Class ModuleVistor |
[hide private]
[frames] | no frames]

## Class ModuleVistor
source code

    object --+
             |
            ModuleVistor

Instance Methods | [hide private]
| __init__(self, system, modname) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
| default(self, node)
| postpone(self, docable, node)
| visitModule(self, node)
| visitClass(self, node)
| visitFrom(self, node)
| visitImport(self, node)
| visitFunction(self, node)
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, system, modname) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### default(self, node) | source code

### postpone(self, docable, node) | source code

### visitModule(self, node) | source code

### visitClass(self, node) | source code

### visitFrom(self, node) | source code

### visitImport(self, node) | source code

### visitFunction(self, node) | source code